@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: G711.c,v 1.27 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: G711.c,v 1.29 2024/01/08 00:11:11 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define RECOBE_COMPAT   VMAJOR
@@ -267,8 +267,9 @@ recobe_G711Atest(int fi, u_char *buf, size_t l) {
     size_t i;
 
     fi = fi % testL;
+    if  (0 > fi) fi += testL;
     for (i = 0; i < l; ++i) {
-        buf[i] = Atest_T[(fi + i) % testL];
+        buf[i] = Atest_T[((size_t)fi + i) % testL];
     }
     return(testL);
 }
@@ -282,8 +283,9 @@ recobe_G711utest(int fi, u_char *buf, size_t l) {
     size_t i;
 
     fi = fi % testL;
+    if  (0 > fi) fi += testL;
     for (i = 0; i < l; ++i) {
-        buf[i] = utest_T[(fi + i) % testL];
+        buf[i] = utest_T[((size_t)fi + i) % testL];
     }
     return(testL);
 }
@@ -315,18 +317,18 @@ static const recobe_c_tnm
 encolist[G711_L] =                                                                               /****
                                                                                                   ****
  *****************************************************************************************************/
-{ { NULL,    NULL, NULL}
-, { "A" , &code_A, NULL}
-, { "u" , &code_u, NULL}
+{ { NULL                , NULL   , NULL}
+, { (const u_char *)"A" , &code_A, NULL}
+, { (const u_char *)"u" , &code_u, NULL}
 };
 
-static int
+static u_int
 /*****************************************************************************************************
                                                                                                   ****/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    int i, r = 0;
+    u_int i, r = 0;
 
     for (i = 1; i < G711_L; ++i) {
         if  (nm[0] == encolist[i].encoid[0]) {
@@ -368,13 +370,13 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encosrc = codnumbyid(name);
+        cnv.encosrc = codnumbyid((const u_char *)name);
         if  (!name[1]) {
             cnv.nonedst = 1;
         } else if (!!name[2]) {
             cnv.encodst = 0;
         } else {
-            cnv.encodst = codnumbyid(&name[1]);
+            cnv.encodst = codnumbyid((const u_char *)&name[1]);
     }   }
     return(cnv);
 }
@@ -385,4 +387,14 @@ const recobe_c_tdm
 recobe_G711_dm =                                                                                 /****
  *****************************************************************************************************
  *****************************************************************************************************/
-{G711_L, 1, "G711", encolist, codnumbyid, convbyname, {reconv}};
+{ G711_L
+, 1
+#ifdef __amd64__
+, 0
+#endif
+, "G711"
+, encolist
+, codnumbyid
+, convbyname
+, {reconv}
+};
