@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2020 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2020..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,11 +24,15 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2020 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: bysh.c,v 1.1 2020/07/07 11:37:57 babolo Exp $"
+#ident "@(#) Copyright (C)2020..2024 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: bysh.c,v 1.2 2024/01/08 00:11:11 babolo Exp $"
 
 #include <sys/types.h>
 
+extern const u_int16_t recobe_bysh[7][256];
+
+/*  recobe.h recobe_bysh   const u_char recobe_bysh[7][256][2] */
+
 const u_int16_t recobe_bysh[7][256] =
 { { 0x0000, 0x0002, 0x0004, 0x0006,   0x0008, 0x000A, 0x000C, 0x000E
   , 0x0010, 0x0012, 0x0014, 0x0016,   0x0018, 0x001A, 0x001C, 0x001E
