@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2016..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2016..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2016..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: code.c,v 1.17 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2016..2025 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: code.c,v 1.24 2025/01/30 03:33:17 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -102,43 +102,33 @@ static const recobe_c_tnm
 encolist[CODE_L] =                                                                               /****
                                                                                                   ****
  *****************************************************************************************************/
-{ { NULL, NULL,     NULL}
-#define CODE0  1
-, { "0" , &kode_0,  NULL}
-#define CODE1  2
-, { "1" , &kode_1,  NULL}
-#define CODE2  3
-, { "2" , &kode_2,  NULL}
-#define CODE3  4
-, { "3" , &kode_3,  NULL}
-#define CODE4  5
-, { "4" , &kode_4,  NULL}
-#define CODE5  6
-, { "5" , &kode_5,  NULL}
-#define CODE6  7
-, { "6" , &kode_6,  NULL}
-#define CODE7  8
-, { "7" , &kode_7,  NULL}
-#define CODEB  9
-, { "B" , &kode_B,  NULL}
-#define CODEQ 10
-, { "Q" , &kode_Q,  NULL}
+{ { NULL                , NULL   , NULL}
+, { (const u_char *)"0" , &kode_0, NULL}
+, { (const u_char *)"1" , &kode_1, NULL}
+, { (const u_char *)"2" , &kode_2, NULL}
+, { (const u_char *)"3" , &kode_3, NULL}
+, { (const u_char *)"4" , &kode_4, NULL}
+, { (const u_char *)"5" , &kode_5, NULL}
+, { (const u_char *)"6" , &kode_6, NULL}
+, { (const u_char *)"7" , &kode_7, NULL}
+, { (const u_char *)"B" , &kode_B, NULL}
+, { (const u_char *)"Q" , &kode_Q, NULL}
 #define CODEX 11
-, { "X" , &kode_X,  NULL}
+, { (const u_char *)"X" , &kode_X, NULL}
 #define CODED 12
-, { "D" , &kode_D,  NULL}
+, { (const u_char *)"D" , &kode_D, NULL}
 #define CODEH 13
-, { "H" , &kode_H,  NULL}
+, { (const u_char *)"H" , &kode_H, NULL}
 };
 
-static int
+static u_int
 /*****************************************************************************************************
                                                                                                   ****/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    int   r = 0;
-    int   i;
+    u_int   r = 0;
+    u_int   i;
 
     for (i = 1; i < CODE_L; ++i) {
         if  (nm[0] == encolist[i].encoid[0]) {
@@ -159,13 +149,13 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encosrc = codnumbyid(name);
+        cnv.encosrc = (u_int64_t)codnumbyid((const u_char *)name);
         if  (!name[1]) {
             cnv.nonedst = 1;
         } else if (!!name[2]) {
             cnv.encodst = 0;
         } else {
-            cnv.encodst = codnumbyid(&name[1]);
+            cnv.encodst = (u_int64_t)codnumbyid((const u_char *)&name[1]);
     }   }
     return(cnv);
 }
@@ -188,12 +178,13 @@ toch(recobe_chain *chain, recobe_chunk *chunk, int64_t ln, u_int64_t word) {
               , chunk->size
               );
     if  (chunk->size < chunk->length + ln) {
-        ifBLIN_QX0("size=%u < length=%u + outwlen=%u", chunk->size, chunk->length, ln);
+        ifBLIN_QX0("size=%u < length=%u + outwlen=%"BLIN_O"u", chunk->size, chunk->length, ln);
         errno = ENOSPC;
         ex = -EX_CANTCREAT;
     } else {
-        recobe_store(&chunk->chunk[chunk->length], -ln, word);
-        chunk->length += (ex = ln);
+        recobe_store(&chunk->chunk[chunk->length], -(ssize_t)ln, word);
+        ex = (int)ln;
+        chunk->length += ln;
     }
     ifBLIN_QX3("- %d", ex);
     return(ex);
@@ -276,7 +267,7 @@ Hn(recobe_chain *chain, recobe_chunk *chunk) {
 
             free(next);
             chain->next = t;
-            ifBLIN_QX4("%08X %"BLIN_X, fl, t);
+            ifBLIN_QX4("%08X %"BLIN_X, fl, BLIN_I(t));
     }   }
     pos = chain->tail->position;
     for (state = 0, curcy = maxcy; state < htref.szt; --curcy) {
@@ -287,7 +278,7 @@ Hn(recobe_chain *chain, recobe_chunk *chunk) {
             goto out;
         }
         if  (!curcy) {
-            state = ~0;
+            state = ~0U;
             ifBLIN_QX0("infinite loop %u", maxcy);
             ex = -EX_SOFTWARE;
             errno = EDOOFUS;
@@ -303,7 +294,7 @@ Hn(recobe_chain *chain, recobe_chunk *chunk) {
             ex = nxt(chain, chunk, pos);
             goto out;
         }
-        ifBLIN_QX4("%02X(%c)", word, word);
+        ifBLIN_QX4("%02"BLIN_O"X(%c)", word, (char)word);
         pw = (char *)&word;
         state = babolo_testchar(&htref, state, &pw);
     }
@@ -334,7 +325,7 @@ Hn(recobe_chain *chain, recobe_chunk *chunk) {
                 ex = nxt(chain, chunk, pos);
                 goto out;
             }
-            ochr = (ochr * 10) + (word - '0');
+            ochr = (ochr * 10) + ((u_int32_t)word - '0');
         }
     } else if (RECOBE_DECOHEX == ochr) {
         if  (RECOBE_XCONV & ~fl) {
@@ -353,11 +344,11 @@ Hn(recobe_chain *chain, recobe_chunk *chunk) {
             }
             if  (';' == word) break;
             if  (('0' <= word) && (word <= '9')) {
-                ochr = (ochr << 4) | (word - '0');
+                ochr = (ochr << 4) | ((u_int32_t)word - '0');
             } else if (('A' <= word) && (word <= 'F')) {
-                ochr = (ochr << 4) | (word - 'A' + 10);
+                ochr = (ochr << 4) | ((u_int32_t)word - 'A' + 10);
             } else if (('a' <= word) && (word <= 'f')) {
-                ochr = (ochr << 4) | (word - 'a' + 10);
+                ochr = (ochr << 4) | ((u_int32_t)word - 'a' + 10);
             } else {
                 ifBLIN_QX1("");
                 ex = nxt(chain, chunk, pos);
@@ -468,14 +459,14 @@ BT(recobe_chain *chain, recobe_chunk *chunk) {
  *****************************************************************************************************/
 #   define blin_internal_flags (chain->flags)
     u_int32_t     control;
-    int           state;
+    u_int         state;
     int           ex = 0;
     ssize_t       intail;
     u_int32_t     ochr;
     const u_char *ichr;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (intail < 1) {
         ex = -1;
         goto out;
@@ -488,17 +479,17 @@ BT(recobe_chain *chain, recobe_chunk *chunk) {
                       , pn
                       , statenames
                       , clasnames[b64d[*ichr] & 0xFF]
-                      , (char*)ichr
-                      , intail
+                      , (const char*)ichr
+                      , (size_t)intail
                       , control
                       , state
                       , ochr
                       , b64d[*ichr]
                       );
-        if  (control & C0) ochr = b64d[*ichr] << 18;
-        if  (control & C1) ochr |= b64d[*ichr] << 12;
-        if  (control & C2) ochr |= b64d[*ichr] << 6;
-        if  (control & C3) ochr |= b64d[*ichr];
+        if  (control & C0) ochr = (u_int32_t)b64d[*ichr] << 18;
+        if  (control & C1) ochr |= (u_int32_t)b64d[*ichr] << 12;
+        if  (control & C2) ochr |= (u_int32_t)b64d[*ichr] << 6;
+        if  (control & C3) ochr |= (u_int32_t)b64d[*ichr];
         if  (control & Ca) {
             ifBLIN_QX1("Trunc 1");
             ex = recobe_outword(chain, chunk, ochr >> 16);
@@ -528,7 +519,7 @@ BT(recobe_chain *chain, recobe_chunk *chunk) {
                 ex = toch(chain, chunk, 2, ochr >> 8);
         }   }
         if  (control & Cd) {
-            ex = toch(chain, chunk, 3, ochr);
+            (void)toch(chain, chunk, 3, ochr);
             ex = 3;
         }
         if  (control & Cx) {
@@ -550,20 +541,20 @@ static int
 TB(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    int           ex = 0;
+#   define blin_internal_flags (chain->flags)
+    int           ex    = 0;
     ssize_t       intail;
-    u_int32_t     ochr;
-    const u_char *ichr;
-    int           blen;
+    u_int32_t     ochr  ;
+    const u_char *ichr  ;
+    int           blen  = -1;
     struct {
         int   max;
         int   cur;
-        char  in[];
-    }            *parm;
+        char  in [];
+    }            *parm  ;
 
-#   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X" %"BLIN_X, chain->flags, BLIN_I(chain), BLIN_I(chain->converdata));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (intail < 1) {
         ex = -EX_DATAERR;
         errno = EINVAL;
@@ -573,7 +564,7 @@ TB(recobe_chain *chain, recobe_chunk *chunk) {
         chain->flags |= RECOBE_USED;
         parm = calloc(1, sizeof(*parm) + 1 + (!chain->converdata ? 0 : strlen(chain->converdata)));
         if  (!parm) {
-            ifBLIN_QW0("No mem %d", sizeof(*parm));
+            ifBLIN_QW0("No mem %zd", sizeof(*parm));
             ex = -EX_OSERR;
             goto out;
         }
@@ -588,29 +579,29 @@ TB(recobe_chain *chain, recobe_chunk *chunk) {
         parm->cur = 0;
         parm->max = 0;
         if  (!!*(parm->in)) {
-            parm->max = strtoul(parm->in, NULL, 0);
+            parm->max = (int)strtol(parm->in, NULL, 0);
     }   }
     ichr = recobe_chunktext(chain->tail);
     switch(intail) {
     case 1:
-        ochr = recobe_load(ichr, -1) << 16;
+        ochr = (u_int32_t)recobe_load(ichr, -1) << 16;
         chain->tail->position += 1;
         blen = 2;
         break;
     case 2:
-        ochr = recobe_load(ichr, -2) << 8;
+        ochr = (u_int32_t)recobe_load(ichr, -2) << 8;
         chain->tail->position += 2;
         blen = 3;
         break;
     default:
-        ochr = recobe_load(ichr, -3);
+        ochr = (u_int32_t)recobe_load(ichr, -3);
         chain->tail->position += 3;
         blen = 4;
     }
     parm = chain->converdata;
     for (int i = 0; i < 4; ++i) {
         if  (i < blen) {
-            ex = recobe_outword(chain, chunk, b64e[(ochr >> (6 * (3 - i))) & 0x3F]);
+            ex = recobe_outword(chain, chunk, (u_int64_t)b64e[(ochr >> (6 * (3 - i))) & 0x3F]);
         } else {
             ex = recobe_outword(chain, chunk, '=');
         }
@@ -707,6 +698,7 @@ static int
 QT(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
+#   define blin_internal_flags (chain->flags)
     u_int32_t     control;
     int           state;
     int           ex = 0;
@@ -718,9 +710,8 @@ QT(recobe_chain *chain, recobe_chunk *chunk) {
         char    in[];
     }            *parm;
 
-#   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X" %"BLIN_X, chain->flags, BLIN_I(chain), BLIN_I(chain->converdata));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (intail < 1) {
         ex = -1;
         goto out;
@@ -729,7 +720,7 @@ QT(recobe_chain *chain, recobe_chunk *chunk) {
         chain->flags |= RECOBE_USED;
         parm = calloc(1, sizeof(*parm) + 1 + (!chain->converdata ? 0 : strlen(chain->converdata)));
         if  (!parm) {
-            ifBLIN_QW0("No mem %d", sizeof(*parm));
+            ifBLIN_QW0("No mem %zd", sizeof(*parm));
             ex = -1;
             goto out;
         }
@@ -741,7 +732,7 @@ QT(recobe_chain *chain, recobe_chunk *chunk) {
         }
         chain->converdata = parm;
         chain->flags |= RECOBE_CNVDFREE;
-        parm->Q = *(parm->in);
+        parm->Q = (u_char)*(parm->in);
     }
     parm = chain->converdata;
     ichr = recobe_chunktext(chain->tail);
@@ -757,14 +748,14 @@ QT(recobe_chain *chain, recobe_chunk *chunk) {
                       , pn1
                       , statenames1
                       , clasnames1[b16[*ichr] & 0x3F]
-                      , (char*)ichr
-                      , intail
+                      , (const char*)ichr
+                      , (size_t)intail
                       , control
-                      , state
+                      , (u_int32_t)state
                       , ochr
                       , b16[*ichr]
                       );
-        if  (control & (D0 | D2)) ochr = (b16[*ichr] & 0x0F) << 4;
+        if  (control & (D0 | D2)) ochr = (u_int32_t)(b16[*ichr] & 0x0F) << 4;
         if  (control & (D1 | D3)) ochr |= b16[*ichr] & 0x0F;
         if  ((control & Ds) && (0 > (ex = recobe_outword(chain, chunk, ochr)))) {
             ifBLIN_QW1("Ds");
@@ -841,23 +832,25 @@ static int
 TQ(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    u_int32_t     control;
-    int           ex = 0;
-    ssize_t       intail;
-    u_int32_t     ochr;
-    const u_char *ichr;
-    struct {
-        int         max;                         /*                          */
-        int         cur;                         /*                             */
-        int         bord;                        /*        */
-        u_char      Q;                           /*   HEX                                */
-        u_int16_t   tb[256];
-        char        in[];                        /*                      */
-    }            *parm;
-
 #   define blin_internal_flags (chain->flags)
+    u_int32_t     control ;
+    ssize_t       intail  ;
+    u_int32_t     ochr    ;
+    const u_char *ichr    ;
+    struct {
+        int         max   ;                      /*                          */
+        int         cur   ;                      /*                             */
+        int         bord  ;                      /*        */
+        u_char      Q     ;                      /*   HEX                                */
+        u_int8_t    dummy0;
+        u_int16_t   dummy1;
+        u_int16_t   tb    [256];
+        char        in    [];                    /*                      */
+    }            *parm     ;
+    int           ex       = 0;
+
     ifBLIN_QX3("+ %08X %"BLIN_X" %"BLIN_X, chain->flags, BLIN_I(chain), BLIN_I(chain->converdata));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (intail < chain->inwlen) {
         ex = -1;
         goto out;
@@ -866,7 +859,7 @@ TQ(recobe_chain *chain, recobe_chunk *chunk) {
         chain->flags |= RECOBE_USED;
         parm = calloc(1, sizeof(*parm) + 1 + (!chain->converdata ? 0 : strlen(chain->converdata)));
         if  (!parm) {
-            ifBLIN_QW0("No mem %d", sizeof(*parm));
+            ifBLIN_QW0("No mem %zd", sizeof(*parm));
             ex = -1;
             goto out;
         }
@@ -876,25 +869,27 @@ TQ(recobe_chain *chain, recobe_chunk *chunk) {
             free(chain->converdata);
             chain->converdata = NULL;
         }
-        parm->Q = *(parm->in);
+        parm->Q = (u_char)*(parm->in);
         chain->converdata = parm;
         chain->flags |= RECOBE_CNVDFREE;
         bcopy(q16, parm->tb, sizeof(parm->tb));
         parm->tb[parm->Q] = Eh;
         if  (!!*(parm->in)) {
             u_char *p = (u_char*)parm->in;
-            u_char  q, r;
 
             if  (!(b16[*p] & 0x0F)) {
+                u_char q;
+                u_char r;
+
                 for (q = *p; q == *(p++); ) {
                     r = *(p++);
                     parm->tb[r] = *(p++) | Es;
             }   }
             if  (!!*p) {
-                parm->max = strtoul((char*)p, (char**)&p, 0);
+                parm->max = (int)strtol((char*)p, (char**)&p, 0);
             }
             if  (!!*(p++)) {
-                parm->bord = strtoul((char*)p, (char**)&p, 0);
+                parm->bord = (int)strtol((char*)p, (char**)&p, 0);
     }   }   }
     parm = chain->converdata;
     ichr = recobe_chunktext(chain->tail);
@@ -902,7 +897,7 @@ TQ(recobe_chain *chain, recobe_chunk *chunk) {
     --intail;
     chain->tail->position++;
     control = (RECOBE_CLEAR & chain->flags) ? Eh : parm->tb[ochr];
-    ex = Er | control;
+    ex = (int)(Er | control);
     if  (control & Ei) {
         if  (' ' == ochr) control |= Et;
         if  (0 > (ex = recobe_outword(chain, chunk, ochr))) {
@@ -937,12 +932,12 @@ TQ(recobe_chain *chain, recobe_chunk *chunk) {
     if  (!!parm->max && (parm->max <= parm->cur)) {
         control |= El;
     } else if ((control & Et) && !!parm->bord && (parm->bord <= parm->cur)) {
-        u_char c;
+        for (u_int i = (u_int)parm->cur, j = 0; ; ++i) {
+            u_char c;
 
-        for (int i = parm->cur, j = 0; ; ++i) {
-            c = chain->tail->chunk[chain->tail->position + i - parm->cur];
+            c = chain->tail->chunk[chain->tail->position + i - (u_int)parm->cur];
             if  (parm->tb[c] & Eh) j += 2;
-            if  ((i + j) >= parm->max) {
+            if  ((i + j) >= (u_int)parm->max) {
                 control |= El;
                 break;
             }
@@ -971,23 +966,25 @@ static int
 nX(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    u_int32_t     control;
-    int           ex = 0;
-    ssize_t       intail;
-    u_int32_t     ochr;
-    const u_char *ichr;
-    struct {
-        int         max;                         /*                          */
-        int         cur;                         /*                             */
-        int         bord;                        /*        */
-        u_char      Q;                           /*   HEX                                */
-        u_int16_t   tb[256];
-        char        in[];                        /*                      */
-    }            *parm;
-
 #   define blin_internal_flags (chain->flags)
+    u_int32_t     control ;
+    ssize_t       intail  ;
+    u_int32_t     ochr    ;
+    const u_char *ichr    ;
+    struct {
+        int         max   ;                      /*                          */
+        int         cur   ;                      /*                             */
+        int         bord  ;                      /*        */
+        u_char      Q     ;                      /*   HEX                                */
+        u_int8_t    dummy0;
+        u_int16_t   dummy1;
+        u_int16_t   tb    [256];
+        char        in    [];                    /*                      */
+    }            *parm    ;
+    int           ex      = 0;
+
     ifBLIN_QX3("+ %08X %"BLIN_X" %"BLIN_X, chain->flags, BLIN_I(chain), BLIN_I(chain->converdata));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (intail < chain->inwlen) {
         ex = -1;
         goto out;
@@ -996,7 +993,7 @@ nX(recobe_chain *chain, recobe_chunk *chunk) {
         chain->flags |= RECOBE_USED;
         parm = calloc(1, sizeof(*parm) + 1 + (!chain->converdata ? 0 : strlen(chain->converdata)));
         if  (!parm) {
-            ifBLIN_QW0("No mem %d", sizeof(*parm));
+            ifBLIN_QW0("No mem %zd", sizeof(*parm));
             ex = -1;
             goto out;
         }
@@ -1006,25 +1003,27 @@ nX(recobe_chain *chain, recobe_chunk *chunk) {
             free(chain->converdata);
             chain->converdata = NULL;
         }
-        parm->Q = *(parm->in);
+        parm->Q = (u_char)*(parm->in);
         chain->converdata = parm;
         chain->flags |= RECOBE_CNVDFREE;
         bcopy(q16, parm->tb, sizeof(parm->tb));
         parm->tb[parm->Q] = Eh;
         if  (!!*(parm->in)) {
             u_char *p = (u_char*)parm->in;
-            u_char  q, r;
 
             if  (!(b16[*p] & 0x0F)) {
+                u_char q;
+                u_char r;
+
                 for (q = *p; q == *(p++); ) {
                     r = *(p++);
                     parm->tb[r] = *(p++) | Es;
             }   }
             if  (!!*p) {
-                parm->max = strtoul((char*)p, (char**)&p, 0);
+                parm->max = (int)strtol((char*)p, (char**)&p, 0);
             }
             if  (!!*(p++)) {
-                parm->bord = strtoul((char*)p, (char**)&p, 0);
+                parm->bord = (int)strtol((char*)p, (char**)&p, 0);
     }   }   }
     parm = chain->converdata;
     ichr = recobe_chunktext(chain->tail);
@@ -1032,7 +1031,7 @@ nX(recobe_chain *chain, recobe_chunk *chunk) {
     --intail;
     chain->tail->position++;
     control = (RECOBE_CLEAR & chain->flags) ? Eh : parm->tb[ochr];
-    ex = Er | control;
+    ex = (int)(Er | control);
     if  (control & Ei) {
         if  (' ' == ochr) control |= Et;
         if  (0 > (ex = recobe_outword(chain, chunk, ochr))) {
@@ -1067,12 +1066,12 @@ nX(recobe_chain *chain, recobe_chunk *chunk) {
     if  (!!parm->max && (parm->max <= parm->cur)) {
         control |= El;
     } else if ((control & Et) && !!parm->bord && (parm->bord <= parm->cur)) {
-        u_char c;
+        for (u_int i = (u_int)parm->cur, j = 0; ; ++i) {
+            u_char c;
 
-        for (int i = parm->cur, j = 0; ; ++i) {
-            c = chain->tail->chunk[chain->tail->position + i - parm->cur];
+            c = chain->tail->chunk[chain->tail->position + i - (u_int)parm->cur];
             if  (parm->tb[c] & Eh) j += 2;
-            if  ((i + j) >= parm->max) {
+            if  ((i + j) >= (u_int)parm->max) {
                 control |= El;
                 break;
             }
@@ -1101,15 +1100,16 @@ static int
 nH(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
+#   define blin_internal_flags (chain->flags)
     u_int64_t     wchr;
     u_int32_t     pos;
     int           ex;
 
-#   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
     pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     if  ((wchr <= RECOBE_DECOHEX) || (wchr >= RECOBE_DECOMAX) || !htext[wchr]) {
@@ -1127,7 +1127,7 @@ nH(recobe_chain *chain, recobe_chunk *chunk) {
             goto out;
         }
         for (int i = 0; !!htext[wchr][i]; ++i) {
-            if  (0 > (ex = recobe_outword(chain, chunk, htext[wchr][i]))) {
+            if  (0 > (ex = recobe_outword(chain, chunk, (u_int64_t)htext[wchr][i] & 0x0FF))) {
                 ex = 0;
                 ifBLIN_QW2("outword");
                 chain->tail->position = pos;
@@ -1151,18 +1151,19 @@ static int
 nD(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    char         *format;
+#   define blin_internal_flags (chain->flags)
+    const char   *format;
     u_int64_t     wchr;
     char          buf[RECOBE_DECMAX];
     u_int32_t     pos;
     int           ex;
     char          f[15];
 
-#   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
     pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     if  (*encolist[chain->cnv.encodst].encoid == 'D') {
@@ -1188,7 +1189,7 @@ nD(recobe_chain *chain, recobe_chunk *chunk) {
         }
     } else {
         for (int i = 0; !!buf[i]; ++i) {
-            if  (0 > (ex = recobe_outword(chain, chunk, buf[i]))) {
+            if  (0 > (ex = recobe_outword(chain, chunk, (u_int64_t)buf[i]))) {
                 ex = 0;
                 chain->tail->position = pos;
                 ifBLIN_QW2("outword");
@@ -1206,36 +1207,37 @@ static int
 Qn(recobe_chain *chain, recobe_chunk *chunk) {                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    u_int32_t   inlen;                    /*                                    */
-    u_int32_t   blen;                     /*  -                        */
-    u_int32_t   elen;                     /*  -                         */
-    u_int64_t   wchr;                     /*                                   */
-    int         ex = 0;                   /* 0<=    , 0>   */
-    const char *b = chain->bcode;         /* -                                */
-    const char *e = chain->ecode;         /* -                                 */
-    char       *p;                        /*             */
-    int         i;                        /*                            */
-
 #   define blin_internal_flags (chain->flags)
+    u_int32_t   inlen;                    /*                                    */
+    u_int32_t   blen ;                    /*  -                        */
+    u_int32_t   elen ;                    /*  -                         */
+    int         ex   = 0;                 /* 0<=    , 0>   */
+    const char *b    = chain->bcode;      /* -                                */
+    const char *e    = chain->ecode;      /* -                                 */
+    char       *p    ;                    /*             */
+
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    blen = !b ? 0 : strlen(b);
-    elen = !e ? 0 : strlen(e);
+    blen = !b ? 0 : (u_int32_t)strlen(b);
+    elen = !e ? 0 : (u_int32_t)strlen(e);
     inlen = recobe_chunksize(chain->tail);
     p = (char *)&chain->tail->chunk[chain->tail->position];
     if  (!blen || (p == strnstr(p, b, inlen))) {
+        u_int64_t wchr;                   /*                                   */
+        int       i   ;                   /*                            */
+
         ex += blen;
         p += blen;
         i = 2 * chain->outwlen;
         for (wchr = 0; 0 < i; ex++, ++p) {
             if  ((*p >= '0') && (*p <= '9')) {
                 wchr <<= 4;
-                wchr += *p - '0';
+                wchr += (u_int64_t)(*p - '0');
             } else if ((*p >= 'A') && (*p <= 'F')) {
                 wchr <<= 4;
-                wchr += *p - 'A' + 10;
+                wchr += (u_int64_t)(*p - 'A' + 10);
             } else if ((*p >= 'a') && (*p <= 'f')) {
                 wchr <<= 4;
-                wchr += *p - 'a' + 10;
+                wchr += (u_int64_t)(*p - 'a' + 10);
             } else {
                 break;
             }
@@ -1244,7 +1246,7 @@ Qn(recobe_chain *chain, recobe_chunk *chunk) {
         inlen = recobe_chunksize(chain->tail);
         if  (!e || (p == strnstr(p, e, inlen))) {
             ex += elen;
-            chain->tail->position += ex;
+            chain->tail->position += (u_int)ex;
             if  (0 > recobe_outword(chain, chunk, wchr)) {
                 ex = -EX_SOFTWARE;
                 ifBLIN_QW2("outword");
@@ -1417,7 +1419,7 @@ static int
 param(recobe_chain *chain) {                                                                     /****
                                                                                                   ****
  *****************************************************************************************************/
-    BLIN_flag     fl;
+    BLIN_flag     fl = 0;
 
     chain->convertor = intercode[chain->cnv.encosrc][chain->cnv.encodst];
     chain->inwlen = interinwlen[chain->cnv.encosrc][chain->cnv.encodst];
@@ -1456,7 +1458,7 @@ param(recobe_chain *chain) {
                 chain->inwlen = chain->next->inwlen;
                 free(chain->next);
                 chain->next = t;
-                ifBLIN_QX4("%08X %"BLIN_X, fl, t);
+                ifBLIN_QX4("%08X %"BLIN_X, fl, BLIN_I(t));
             } else {
                 chain->inwlen = chain->next->outwlen;
         }   }
@@ -1475,4 +1477,14 @@ recobe_code_dm =
                                                                                                   ****
  *****************************************************************************************************
  *****************************************************************************************************/
-{CODE_L, 2, "CODE", encolist, codnumbyid, convbyname, {.param = param}};
+{ CODE_L
+, 2
+# ifdef __amd64__
+, 0
+# endif
+, "CODE"
+, encolist
+, codnumbyid
+, convbyname
+, {.param = param}
+};
