@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2012..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2012..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2012..2021 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: crc.c,v 1.10 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2012..2024 @BABOLO http://www.babolo.ru/\n"
+#ident "@(#) $Id: crc.c,v 1.14 2024/07/28 20:09:54 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -79,21 +79,21 @@ static const recobe_c_tnm
 encolist[CRC_L] =                                                                                /****
                                                                                                   ****
  *****************************************************************************************************/
-{ { NULL, NULL,      NULL}
-, { "1" , &crc_1,    NULL}
-, { "2" , &crc_24,   NULL}
-, { "3" , &crc_32,   NULL}
-, { "4" , &crc_itt,  NULL}
-, { "5" , &crc_csum, NULL}
+{ { NULL                , NULL     , NULL}
+, { (const u_char *)"1" , &crc_1   , NULL}
+, { (const u_char *)"2" , &crc_24  , NULL}
+, { (const u_char *)"3" , &crc_32  , NULL}
+, { (const u_char *)"4" , &crc_itt , NULL}
+, { (const u_char *)"5" , &crc_csum, NULL}
 };
 
-static int
+static u_int
 /*****************************************************************************************************
                                                                                                   ****/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    return(babolo_testword(&crc, nm));
+    return(babolo_testword(&crc, (const char *)nm));
 }
 
 static recobe_conv
@@ -107,7 +107,7 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encodst = codnumbyid(name);
+        cnv.encodst = codnumbyid((const u_char *)name);
     }
     cnv.domain = RECOBE_CRC;
     return(cnv);
@@ -162,7 +162,7 @@ crc32(recobe_chain *chain, recobe_chunk *chunk) {
     int           j;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (!(chain->flags & RECOBE_USED)) {
         r = (u_int32_t *)&chain->converdata;
         *r = CRC32_INIT;
@@ -205,14 +205,14 @@ recobe_crc24(const u_char *octets, ssize_t len) {
     r = CRC24_INIT;
     if  (len < 0) {
         for (i = -len; i > 0;) {
-            r ^= octets[--i] << 16;
+            r ^= (u_int32_t)octets[--i] << 16;
             for (j = 0; j < 8; ++j)  {
                 r <<= 1;
                 if  (r & 0x1000000) r ^= CRC24_POLY;
         }   }
     } else {
         for (i = 0; i < len; ++i) {
-            r ^= octets[i] << 16;
+            r ^= (u_int32_t)octets[i] << 16;
             for (j = 0; j < 8; ++j)  {
                 r <<= 1;
                 if  (r & 0x1000000) r ^= CRC24_POLY;
@@ -235,7 +235,7 @@ crc24(recobe_chain *chain, recobe_chunk *chunk) {
     int           j;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (!(chain->flags & RECOBE_USED)) {
         r = (u_int32_t *)&chain->converdata;
         *r = CRC24_INIT;
@@ -322,9 +322,9 @@ recobe_crccitt(const u_char *octets, ssize_t len) {
 
     r = 0;
     if  (len < 0) {
-        for (i = -len; i > 0;) r = (r << 8) ^ crccitt[((r >> 8) ^ octets[--i]) & 0x00FF];
+        for (i = -len; i > 0;) r = (u_int16_t)(r << 8) ^ crccitt[((r >> 8) ^ octets[--i]) & 0x00FF];
     } else {
-        for (i = 0; i < len;) r = (r << 8) ^ crccitt[((r >> 8) ^ octets[i++]) & 0x00FF];
+        for (i = 0; i < len;) r = (u_int16_t)(r << 8) ^ crccitt[((r >> 8) ^ octets[i++]) & 0x00FF];
     }
     return(r);
 }
@@ -342,7 +342,7 @@ ccitt(recobe_chain *chain, recobe_chunk *chunk) {
     u_int32_t    *r;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (!(chain->flags & RECOBE_USED)) {
         r = (u_int32_t *)&chain->converdata;
         *r = 0;
@@ -395,7 +395,7 @@ csum(recobe_chain *chain, recobe_chunk *chunk) {
     u_int32_t    *r;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (!(chain->flags & RECOBE_USED)) {
         r = (u_int32_t *)&chain->converdata;
         *r = 0;
@@ -449,7 +449,7 @@ csum1(recobe_chain *chain, recobe_chunk *chunk) {
     u_int32_t    *r;
 
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     if  (!(chain->flags & RECOBE_USED)) {
         r = (u_int32_t *)&chain->converdata;
         *r = 0;
@@ -518,7 +518,7 @@ recobe_opens(recobe_conf *cf, const char *p, recobe_chain *next) {
 
     ifBLIN_QX3("+ w:%s %"BLIN_X, p, BLIN_I(next));
     if  (!(chain = malloc(sizeof(recobe_chain)))) {
-        ifBLIN_QW0("malloc(%d)", sizeof(recobe_chain));
+        ifBLIN_QW0("malloc(%zd)", sizeof(recobe_chain));
         goto out;
     }
     chain->cnv = convbyname(p);
@@ -547,7 +547,7 @@ recobe_opens(recobe_conf *cf, const char *p, recobe_chain *next) {
     chain->outwnum = 1;
 out:
     RECOBE_CHAIN(chain);
-    ifBLIN_QX3("- %"BLIN_X, chain);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chain));
     return(chain);
 #   undef blin_internal_flags
 }
@@ -562,4 +562,14 @@ recobe_crc_dm =
                                                                                                   ****
  *****************************************************************************************************
  *****************************************************************************************************/
-{CRC_L, 4, "CRC", encolist, codnumbyid, convbyname, {NULL}};
+{ CRC_L
+, 4
+#ifdef __amd64__
+, 0
+#endif
+, "CRC"
+, encolist
+, codnumbyid
+, convbyname
+, {NULL}
+};
