@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: etat.c,v 1.23 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: etat.c,v 1.25 2024/01/08 00:11:11 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -46,7 +46,7 @@
 
 static const u_char
 /*****************************************************************************************************/
-ai[256] =                                                                                        /****
+ai[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -71,7 +71,7 @@ ai[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ia[256] =                                                                                        /****
+ia[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -96,7 +96,7 @@ ia[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ik[256] =                                                                                        /****
+ik[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -121,7 +121,7 @@ ik[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ki[256] =                                                                                        /****
+ki[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -146,7 +146,7 @@ ki[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ak[256] =                                                                                        /****
+ak[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -171,7 +171,7 @@ ak[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ka[256] =                                                                                        /****
+ka[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -196,7 +196,7 @@ ka[256] =
 
 static const u_char
 /*****************************************************************************************************/
-aw[256] =                                                                                        /****
+aw[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -221,7 +221,7 @@ aw[256] =
 
 static const u_char
 /*****************************************************************************************************/
-wa[256] =                                                                                        /****
+wa[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -246,7 +246,7 @@ wa[256] =
 
 static const u_char
 /*****************************************************************************************************/
-iw[256] =                                                                                        /****
+iw[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -271,7 +271,7 @@ iw[256] =
 
 static const u_char
 /*****************************************************************************************************/
-wi[256] =                                                                                        /****
+wi[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -296,7 +296,7 @@ wi[256] =
 
 static const u_char
 /*****************************************************************************************************/
-kw[256] =                                                                                        /****
+kw[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -321,7 +321,7 @@ kw[256] =
 
 static const u_char
 /*****************************************************************************************************/
-wk[256] =                                                                                        /****
+wk[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -346,7 +346,7 @@ wk[256] =
 
 static const u_char
 /*****************************************************************************************************/
-za[256] =                                                                                        /****
+za[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -371,7 +371,7 @@ za[256] =
 
 static const u_char
 /*****************************************************************************************************/
-az[256] =                                                                                        /****
+az[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -396,7 +396,7 @@ az[256] =
 
 static const u_char
 /*****************************************************************************************************/
-km[256] =                                                                                        /****
+km[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -421,7 +421,7 @@ km[256] =
 
 static const u_char
 /*****************************************************************************************************/
-mk[256] =                                                                                        /****
+mk[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -446,7 +446,7 @@ mk[256] =
 
 static const u_char
 /*****************************************************************************************************/
-wm[256] =                                                                                        /****
+wm[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -471,7 +471,7 @@ wm[256] =
 
 static const u_char
 /*****************************************************************************************************/
-mw[256] =                                                                                        /****
+mw[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -496,7 +496,7 @@ mw[256] =
 
 static const u_char
 /*****************************************************************************************************/
-im[256] =                                                                                        /****
+im[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -521,7 +521,7 @@ im[256] =
 
 static const u_char
 /*****************************************************************************************************/
-mi[256] =                                                                                        /****
+mi[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -546,7 +546,7 @@ mi[256] =
 
 static const u_char
 /*****************************************************************************************************/
-am[256] =                                                                                        /****
+am[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -571,7 +571,7 @@ am[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ma[256] =                                                                                        /****
+ma[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x04, 0x05, 0x06, 0x07,  0x08, 0x09, 0x0A, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x14, 0x15, 0x16, 0x17,  0x18, 0x19, 0x1A, 0x1B,  0x1C, 0x1D, 0x1E, 0x1F
@@ -596,7 +596,7 @@ ma[256] =
 
 static const u_char
 /*****************************************************************************************************/
-ek[256] =                                                                                        /****
+ek[256] = (const u_char[])                                                                       /****
  *****************************************************************************************************/
 {     0, 0x01, 0x02, 0x03,  0x9C, 0x09, 0x86, 0x7F,  0x97, 0x8D, 0x8E, 0x0B,  0x0C, 0x0D, 0x0E, 0x0F
 ,  0x10, 0x11, 0x12, 0x13,  0x9D, 0x85, 0x08, 0x87,  0x18, 0x19, 0x92, 0x8F,  0x1C, 0x1D, 0x1E, 0x1F
@@ -658,20 +658,20 @@ static const recobe_c_tnm
 encolist[ETAT_L] =                                                                               /****
  *****************************************************************************************************/
 { { NULL,    NULL,                 NULL}
-, { "k" , &code_k, recobe_koi8printable}
-, { "w" , &code_w, recobe_nullprintable}
-, { "a" , &code_a, recobe_nullprintable}
-, { "i" , &code_i, recobe_nullprintable}
-, { "m" , &code_m, recobe_nullprintable}
-, { "z" , &code_z, recobe_nullprintable}
-, { "e" , &code_e, recobe_nullprintable}
+, { (const u_char *)"k" , &code_k, recobe_koi8printable}
+, { (const u_char *)"w" , &code_w, recobe_nullprintable}
+, { (const u_char *)"a" , &code_a, recobe_nullprintable}
+, { (const u_char *)"i" , &code_i, recobe_nullprintable}
+, { (const u_char *)"m" , &code_m, recobe_nullprintable}
+, { (const u_char *)"z" , &code_z, recobe_nullprintable}
+, { (const u_char *)"e" , &code_e, recobe_nullprintable}
 };
 
-static int
+static u_int
 /*****************************************************************************************************/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
  *****************************************************************************************************/
-    int i, r = 0;
+    u_int i, r = 0;
 
     for (i = 1; i < ETAT_L; ++i) {
         if  (nm[0] == encolist[i].encoid[0]) {
@@ -709,13 +709,13 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encosrc = codnumbyid(name);
+        cnv.encosrc = codnumbyid((const u_char *)name);
         if  (!name[1]) {
             cnv.nonedst = 1;
         } else if (!!name[2]) {
             cnv.encodst = 0;
         } else {
-            cnv.encodst = codnumbyid(&name[1]);
+            cnv.encodst = codnumbyid((const u_char *)&name[1]);
     }   }
     return(cnv);
 }
@@ -726,4 +726,15 @@ const recobe_c_tdm
 recobe_etat_dm =                                                                                 /****
  *****************************************************************************************************
  *****************************************************************************************************/
-{ETAT_L, 1, "ETAT", encolist, codnumbyid, convbyname, {reconv}};
+{ ETAT_L
+, 1
+#ifdef __amd64__
+, 0
+#endif
+, "ETAT"
+, encolist
+, codnumbyid
+, convbyname
+, {reconv}
+};
+
