@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2016..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2016..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2016..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: maint.c,v 1.15 2022/08/28 00:56:28 babolo Exp $"
+#ident "@(#) Copyright (C)2016..2024 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: maint.c,v 1.20 2024/01/14 20:15:08 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -122,13 +122,13 @@ int
 /*****************************************************************************************************
  *****************************************************************************************************
                                                                                                   ****/
-recobe_PrintWideStr(const char *p) {                                                             /****
+recobe_PrintWideStr(const u_char *p) {                                                           /****
                                                                                                   ****
  *****************************************************************************************************
  *****************************************************************************************************/
     int    ex = EX_OK;
-    u_char t[65536];
     int    no = 0;
+    u_char t  [65536];
 
     switch(p[0]) {
     case 'U':                                                     /*   recobe_ud[] */
@@ -155,16 +155,16 @@ recobe_PrintWideStr(const char *p) {
         /* FALLTHROUGH */
     case 'K': {                                          /*    recobe_1k[] */
             FILE *nil = fopen("/dev/null", "w");
-            int   virtualpos;
-            int   realpos;
-            int   shift;
+            int   virtualpos = 0;
+            int   realpos    = 0;
+            int   shift      ;
 
             if  (!nil) {
                 ifBLIN_QW0("fopen(/dev/null, w)");
                 goto out;
             }
             printf("/*-\n"
-" * Copyright (C)2018..2021 @BABOLO http://www.babolo.ru/\n"
+" * Copyright (C)2018..2024 @BABOLO http://www.babolo.ru/\n"
 " * All rights reserved.\n"
 " *\n"
 " * Redistribution and use in source and binary forms, with or without\n"
@@ -188,8 +188,8 @@ recobe_PrintWideStr(const char *p) {
 " * SUCH DAMAGE.\n"
 " */\n"
 "\n"
-"#ident \"@(#) Copyright (C)2018..2021 @BABOLO http://www.babolo.ru/\"\n"
-"#ident \"@(#) $Id: maint.c,v 1.15 2022/08/28 00:56:28 babolo Exp $\"\n"
+"#ident \"@(#) Copyright (C)2018..2024 @BABOLO http://www.babolo.ru/\"\n"
+"#ident \"@(#) $Id: maint.c,v 1.20 2024/01/14 20:15:08 babolo Exp $\"\n"
 "\n"
 "#include <stdio.h>\n"
 "#define NO NULL\n"
@@ -201,7 +201,7 @@ recobe_1k[65536] =
  **************************************************************************************************\n\
  **************************************************************************************************/\n\
 ");
-            for (int i = 0; i < 65536; ++i) {
+            for (u_int i = 0; i < 65536; ++i) {
                 int next = 0;
                 int now = 0;
 
@@ -216,7 +216,7 @@ recobe_1k[65536] =
                 switch(shift) {
                 case 0:
                     if  (!!i && ((!!no && !now) || (0 > now))) {
-                        realpos += printf("%c  NO", !i ? '{' : ',');
+                        realpos += printf(",  NO");
                         goto caseout;
                     } else {
                         realpos += printf("%c  \"", !i ? '{' : ',');
@@ -224,7 +224,7 @@ recobe_1k[65536] =
                     break;
                 case 1:
                     if  (!!i && ((!!no && !now) || (0 > now))) {
-                        realpos += printf("%c NO", !i ? '{' : ',');
+                        realpos += printf(", NO");
                         goto caseout;
                     } else {
                         realpos += printf("%c \"", !i ? '{' : ',');
@@ -232,7 +232,7 @@ recobe_1k[65536] =
                     break;
                 default:
                     if  (!!i && ((!!no && !now) || (0 > now))) {
-                        realpos += printf("%cNO", !i ? '{' : ',');
+                        realpos += printf(",NO");
                         goto caseout;
                     } else {
                         realpos += printf("%c\"", !i ? '{' : ',');
@@ -256,7 +256,7 @@ recobe_1k[65536] =
         printf("};\n");
         break;
     case 'X':
-        for (int i = 0; i < 65536; ++i) {
+        for (u_int i = 0; i < 65536; ++i) {
             int j;
 
             if  (!recobe_1k[i]) {
@@ -276,9 +276,9 @@ recobe_1k[65536] =
         }   }
         break;
     default:                                            /*    recobe_1k[] */
-        for (int i = 0; i < 65536; ++i) t[i] = 0;
-        for (int i = 0; i < 256; ++i) t[recobe_k1[i]] = i;
-        for (int i = 0; i < 65536; ++i) {
+        for (u_int i = 0; i < 65536; ++i) t[i] = 0;
+        for (u_int i = 0; i < 256; ++i) t[recobe_k1[i]] = (u_char)i;
+        for (u_int i = 0; i < 65536; ++i) {
             if  (  !!t[i]
                 && !!recobe_1k[i][0]
                 && (!(t[i] == (0x0FF & recobe_1k[i][0])) || !!recobe_1k[i][1])
