@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2012..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2012..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2012..2021 @BABOLO http://www.babolo.ru/\n"
-#ident "@(#) $Id: octets.c,v 1.20 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2012..2024 @BABOLO http://www.babolo.ru/\n"
+#ident "@(#) $Id: octets.c,v 1.22 2024/01/08 00:11:11 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -247,9 +247,9 @@ recobe_ustore(u_char *octets, u_int64_t c) {
     for (int i = 0; i < 12; ++i) {
         if  ((m > c) || (12 == i)) {
             if  (!i) {
-                octets[r++] = c;
+                octets[r++] = (u_char)c;
             } else {
-                octets[r++] = (0x00FF << (7 - i)) | (c >> (6 * i));
+                octets[r++] = (u_char)((0x00FFU << (7 - i)) | (c >> (6 * i)));
                 for (; i > 0;) {
                     octets[r++] = 0x0080 | (0x003F & (c >> (6 * --i)));
             }   }
@@ -383,7 +383,7 @@ recobe_cstore(u_char *octets, u_int64_t c) {
     for (i = 0; i < 8; ++i) if  ((0x080ULL << (7 * i)) > c) break;
     for (r = 0; i >= 0; --i) {
         if  (!r) {
-            octets[r++] = (c >> (8 * i)) | (0x00FF << (8 - i));
+            octets[r++] = (u_char)((c >> (8 * i)) | (0x00FFU << (8 - i)));
         } else {
             octets[r++] = (c >> (8 * i)) & 0x00FF;
     }   }
@@ -406,7 +406,7 @@ recobe_loadM(const u_char *octets, const char *mask) {
 
     for (i = 0; !!mask[i]; ++i) {
         if  ((mask[i] < '0') || (mask[i] > '7')) {
-            ifBLIN_QX0("Illegal input %c in %s[%d]", mask[i], mask, i);
+            ifBLIN_QX0("Illegal input %c in %s[%zd]", mask[i], mask, i);
             errno = EINVAL;
             break;
         }
@@ -435,7 +435,7 @@ recobe_storeM(u_char *octets, const char *mask, u_int64_t c) {
             errno = EINVAL;
             break;
         }
-        octets[i] = c >> ((mask[i] - '0') << 3);
+        octets[i] = (u_char)(c >> ((mask[i] - '0') << 3));
     }
     return(i);
 }
