@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/
  * PKG = recobe
  * All rights reserved.
  *
@@ -24,7 +24,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: recobe.h,v 1.77 2021/07/31 08:47:54 babolo Exp $
+ * $Id: recobe.h,v 1.82 2024/03/24 20:28:44 babolo Exp $
  */
 
 #ifndef  _BABOLO_RECOBE_H_
@@ -40,23 +40,22 @@
 
 __BEGIN_DECLS
 
-# define RECOBE_IN         0
-# define RECOBE_TEXT       1
-# define RECOBE_G711       2
-# define RECOBE_ETAT       3
-# define RECOBE_CRC        4
-# define RECOBE_WIDE       5
-# define RECOBE_CODE       6
-# define RECOBE_DOMAX      7
+# define RECOBE_IN         0U
+# define RECOBE_TEXT       1U
+# define RECOBE_G711       2U
+# define RECOBE_ETAT       3U
+# define RECOBE_CRC        4U
+# define RECOBE_WIDE       5U
+# define RECOBE_CODE       6U
+# define RECOBE_DOMAX      7U
 
-# define RECOBE_PREFLEN    256
-# define RECOBE_PUNYMAX    1024
-# define RECOBE_MAXKOIS    9
-# define RECOBE_EOT        0xFFFFFFFF                       /* for recobe_chunk.position             */
+# define RECOBE_PREFLEN    256U
+# define RECOBE_PUNYMAX    1024U
+# define RECOBE_MAXKOIS    9U
 
-# define RECOBE_HCONV      0x000020           /* Decode HTML mnemonic                                */
-# define RECOBE_DCONV      0x000040           /* Decode HTML DEC numeric codes                       */
-# define RECOBE_XCONV      0x000080           /* Decode HTML HEX numeric codes                       */
+# define RECOBE_HCONV      0x000020U          /* Decode HTML mnemonic                                */
+# define RECOBE_DCONV      0x000040U          /* Decode HTML DEC numeric codes                       */
+# define RECOBE_XCONV      0x000080U          /* Decode HTML HEX numeric codes                       */
 
 # define RECOBE_CASE_a do {                                                                           \
     const char       *o;                                                                              \
@@ -224,7 +223,7 @@ __BEGIN_DECLS
 } while(0)
 
 # define RECOBE_CASE_M do {                                                                           \
-    int               i;                                                                              \
+    u_int             i;                                                                              \
     i = babolo_getoptunum(RECOBE_CASE_OPTS->bos, 0) & 0x00FF;                                         \
     if  (!!errno) {                                                                                   \
         ifBLIN_QW0("Illegal -%c arg", RECOBE_CASE_OPTS->bos->c);                                      \
@@ -244,7 +243,7 @@ __BEGIN_DECLS
         ifBLIN_QW0("No mem");                                                                         \
         RECOBE_CASE_EX = -EX_OSERR;                                                                   \
     }                                                                                                 \
-    *(RECOBE_CASE_OPTS->cf.mod) = i;                                                                  \
+    *(RECOBE_CASE_OPTS->cf.mod) = (char)i;                                                                  \
 } while(0)
 
 # define RECOBE_CASE_o do {                                                                           \
@@ -258,7 +257,7 @@ __BEGIN_DECLS
     case 'b': case 'l':                                                                               \
     case 'B': case 'L':                                                                               \
         RECOBE_CASE_OPTS->cf.flags = (RECOBE_CASE_OPTS->cf.flags & ~RECOBE_ORDER)                     \
-                                   | (o[0] & RECOBE_ORDER)                                            \
+                                   | ((u_int)o[0] & RECOBE_ORDER)                                            \
         ;                                                                                             \
         break;                                                                                        \
     default:                                                                                          \
@@ -300,6 +299,7 @@ typedef struct recobe_chunk {
     u_int32_t           size;       /*                              */
     u_int32_t           length;     /*                   */
     u_int32_t           position;   /*        */
+#   define     RECOBE_EOT        0xFFFFFFFF  /*                     */
     u_int32_t           dummy;
     u_char              chunk[0];   /* Byte array    */
 } recobe_chunk;
@@ -312,15 +312,15 @@ typedef int               (*recobe_paramer)(recobe_chain *chain);
 
 struct recobe_chain {
     BLIN_flag           flags;
-#  define      RECOBE_USED       0x000001     /*                              */
-#  define      RECOBE_ORDER      0x000002     /* Big endian (l = 4C, b = 42) !!! ATTENTION 0x02 !!!  */
-#  define      RECOBE_TRACE      0x000004     /* Every conversion stage output                       */
-#  define      RECOBE_CHAINER    0x000008     /* 0 - convertor(chain, newchunk), 1 - puller(chain)   */
-#  define      RECOBE_DOEND      0x000010     /*                                */
-#  define      RECOBE_CLEAR      0x001000     /*   HEX    HEX                         */
-#  define      RECOBE_CNVDFREE   0x002000     /* free(->converdata)                                  */
-#  define      RECOBE_LSTRICT    0x004000     /*     Qn                      */
-#  define      RECOBE_ERHEXPRT   0x080000
+#  define      RECOBE_USED       0x000001U    /*                              */
+#  define      RECOBE_ORDER      0x000002U    /* Big endian (l = 4C, b = 42) !!! ATTENTION 0x02 !!!  */
+#  define      RECOBE_TRACE      0x000004U    /* Every conversion stage output                       */
+#  define      RECOBE_CHAINER    0x000008U    /* 0 - convertor(chain, newchunk), 1 - puller(chain)   */
+#  define      RECOBE_DOEND      0x000010U    /*                                */
+#  define      RECOBE_CLEAR      0x001000U    /*   HEX    HEX                         */
+#  define      RECOBE_CNVDFREE   0x002000U    /* free(->converdata)                                  */
+#  define      RECOBE_LSTRICT    0x004000U    /*     Qn                      */
+#  define      RECOBE_ERHEXPRT   0x080000U
     union {
         u_int32_t           inblock;
         struct {
@@ -345,10 +345,14 @@ struct recobe_chain {
         struct {
             u_int16_t           outwlen;
             u_int16_t           outwnum;
-};  };  };
+    };  };
+# ifdef __amd64__
+    u_int32_t           dummy;
+# endif
+};
 
 typedef struct recobe_c_tnm {                               /*                    */
-    const char         *encoid;                             /*                 */
+    const u_char       *encoid;                             /*                 */
     const char       *(*enconamess)[];                      /*                      */
     const char         *printable;                          /*                      */
 } recobe_c_tnm;
@@ -356,12 +360,15 @@ typedef struct recobe_c_tnm {                               /*
 typedef struct recobe_c_tdm {                               /*          */
     const u_int16_t     recountad;                          /*                    */
     const u_int16_t     family;                             /*                        */
-#  define      RECOBE_C          0x0001
-#  define      RECOBE_K          0x0002
-#  define      RECOBE_S          0x0004
+#  define      RECOBE_C          0x0001U
+#  define      RECOBE_K          0x0002U
+#  define      RECOBE_S          0x0004U
+# ifdef __amd64__
+    u_int32_t           dummy;
+# endif
     const char         *domname;                            /*                              */
     const recobe_c_tnm *encolist;                           /*                      */
-    int               (*codnumbyid)(const char *encoid);    /*     -1     */
+    u_int             (*codnumbyid)(const u_char *encoid);  /*     0      */
     recobe_conv       (*convbyname)(const char *reconm);    /*    reconm    */
     union {
         u_char           *(*reconv)(recobe_conv cnv);       /*    conv         */
@@ -371,6 +378,10 @@ typedef struct recobe_c_tdm {                               /*          */
 
 typedef struct recobe_collection_t {                        /*         */
     const u_int16_t     domcount;                           /*                      */
+    u_int16_t           dummy0;
+# ifdef __amd64__
+    u_int32_t           dummy;
+# endif
     recobe_conv       (*conv)(const char *nm, int domain, u_int16_t family);
                                                             /*         */
     u_char           *(*reconv)(recobe_conv cnv);           /*    conv         */
@@ -380,17 +391,17 @@ typedef struct recobe_collection_t {                        /*         */
 
 struct recobe_conf {
     BLIN_flag     flags;
-#  define      RECOBE_ORDER      0x000002     /* Big endian (l = 4C, b = 42) !!! ATTENTION 0x02 !!!  */
-#  define      RECOBE_TRACE      0x000004     /* Every conversion stage output                       */
-#  define      RECOBE_PRINTABLE  0x000100
-#  define      RECOBE_PRINTATLE  0x000200
-#  define      RECOBE_FULLCHECK  0x000400
-#  define      RECOBE_PRELINERA  0x000800
-#  define      RECOBE_CLEAR      0x001000     /*   HEX    HEX                         */
-#  define      RECOBE_LSTRICT    0x004000     /*     Qn                      */
-#  define      RECOBE_REVERTIZE  0x010000
-#  define      RECOBE_INTERTIZE  0x020000
-#  define      RECOBE_ERHEXPRT   0x080000
+#  define      RECOBE_ORDER      0x000002U    /* Big endian (l = 4C, b = 42) !!! ATTENTION 0x02 !!!  */
+#  define      RECOBE_TRACE      0x000004U    /* Every conversion stage output                       */
+#  define      RECOBE_PRINTABLE  0x000100U
+#  define      RECOBE_PRINTATLE  0x000200U
+#  define      RECOBE_FULLCHECK  0x000400U
+#  define      RECOBE_PRELINERA  0x000800U
+#  define      RECOBE_CLEAR      0x001000U    /*   HEX    HEX                         */
+#  define      RECOBE_LSTRICT    0x004000U    /*     Qn                      */
+#  define      RECOBE_REVERTIZE  0x010000U
+#  define      RECOBE_INTERTIZE  0x020000U
+#  define      RECOBE_ERHEXPRT   0x080000U
     u_int32_t     dummy;
     char         *mod;
     char         *bsubst;
@@ -418,7 +429,7 @@ const u_char *recobe_chunktext  __P((recobe_chunk *chunk));
 int           recobe_close      __P((recobe_chain *chain));                                        /**/
 recobe_chunk *recobe_chunkopy   __P((recobe_chain *chain));                                        /**/
 recobe_chunk *recobe_chainbuf   __P((recobe_chain *chain));                                        /**/
-recobe_chunk *recobe_chainarr   __P((recobe_chain *chain, size_t inlen, void *in));                /**/
+recobe_chunk *recobe_chainarr   __P((recobe_chain *chain, size_t inlen, void const *in));          /**/
 int           recobe_chunksum   __P((recobe_chain *chain, recobe_chunk *source));                  /**/
 recobe_chunk *recobe_chunkat    __P((recobe_chain *chain, recobe_chunk *in0, recobe_chunk *in1));  /**/
 recobe_chain *recobe_openmd     __P((recobe_conf *cf, recobe_mife_p *md, u_int32_t chunksize));    /**/
@@ -648,20 +659,20 @@ void recobe_cnverr       __P(( const char *file
 int  recobe_inword       __P((recobe_chain *chain, recobe_chunk *chunk, u_int64_t *wchr));         /**/
 int  recobe_outword      __P((recobe_chain *chain, recobe_chunk *chunk, u_int64_t wchr));          /**/
                                                                                                   /* */
-int  recobe_TestOrRevert __P((const char *p));                                                   /*  */
-int  recobe_PrintAndMake __P((const char *p));                                                  /*   */
-int  recobe_PrintNoRecod __P((const char *p));                                                 /*    */
-int  recobe_WriteAndMake __P((const char *p));                                                /*     */
-int  recobe_G711DiffConv __P((const char *p));                                               /*      */
-int  recobe_PrintFilling __P((const char *p));                                              /*       */
-int  recobe_InterMediaTo __P((const char *p));                                             /*        */
-int  recobe_EtalonCompar __P((const char *p));                                            /*         */
-int  recobe_ReCalculator __P((const char *p));                                           /*          */
-int  recobe_ReCoordinate __P((const char *p));                                          /*           */
-int  recobe_PrintWideStr __P((const char *p));                                         /*            */
-int  recobe_TramplesDown __P((const char *p));                                        /*             */
-void recobe_p256         __P(( const char *from                                      /*              */
-                             , const char *to                                       /*               */
+int  recobe_TestOrRevert __P((const u_char *p));                                                 /*  */
+int  recobe_PrintAndMake __P((const u_char *p));                                                /*   */
+int  recobe_PrintNoRecod __P((const u_char *p));                                               /*    */
+int  recobe_WriteAndMake __P((const u_char *p));                                              /*     */
+int  recobe_G711DiffConv __P((const u_char *p));                                             /*      */
+int  recobe_PrintFilling __P((const u_char *p));                                            /*       */
+int  recobe_InterMediaTo __P((const u_char *p));                                           /*        */
+int  recobe_EtalonCompar __P((const u_char *p));                                          /*         */
+int  recobe_ReCalculator __P((const u_char *p));                                         /*          */
+int  recobe_ReCoordinate __P((const u_char *p));                                        /*           */
+int  recobe_PrintWideStr __P((const u_char *p));                                       /*            */
+int  recobe_TramplesDown __P((const u_char *p));                                      /*             */
+void recobe_p256         __P(( const u_char *from                                    /*              */
+                             , const u_char *to                                     /*               */
                              , u_int16_t domain                                    /*                */
                              , const u_char array[256]                            /*                 */
                             ));                                                  /*                  */
