@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: text.c,v 1.26 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2014..2024 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: text.c,v 1.28 2024/01/08 00:11:11 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -756,25 +756,25 @@ static const recobe_c_tnm
 /*****************************************************************************************************/
 encolist[TEXT_L] =                                                                               /****
  *****************************************************************************************************/
-{ { NULL,    NULL,                 NULL}
-, { "k" , &code_k, recobe_koi8printable}
-, { "w" , &code_w, recobe_nullprintable}
-, { "a" , &code_a, recobe_nullprintable}
-, { "i" , &code_i, recobe_nullprintable}
-, { "m" , &code_m, recobe_nullprintable}
-, { "z" , &code_z, recobe_nullprintable}
-, { "e" , &code_e, recobe_nullprintable}
-, { "K" , &code_K, recobe_koi8printable}
-, { "Z" , &code_Z, recobe_koi8printable}
-, { "Y" , &code_Y, recobe_koi8printable}
+{ { NULL                , NULL   , NULL                }
+, { (const u_char *)"k" , &code_k, recobe_koi8printable}
+, { (const u_char *)"w" , &code_w, recobe_nullprintable}
+, { (const u_char *)"a" , &code_a, recobe_nullprintable}
+, { (const u_char *)"i" , &code_i, recobe_nullprintable}
+, { (const u_char *)"m" , &code_m, recobe_nullprintable}
+, { (const u_char *)"z" , &code_z, recobe_nullprintable}
+, { (const u_char *)"e" , &code_e, recobe_nullprintable}
+, { (const u_char *)"K" , &code_K, recobe_koi8printable}
+, { (const u_char *)"Z" , &code_Z, recobe_koi8printable}
+, { (const u_char *)"Y" , &code_Y, recobe_koi8printable}
 };
 
-static int
+static u_int
 /*****************************************************************************************************/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
  *****************************************************************************************************/
-    int   r = 0;
-    int   i;
+    u_int   r = 0;
+    u_int   i;
 
     for (i = 1; i < TEXT_L; ++i) {
         if  (nm[0] == encolist[i].encoid[0]) {
@@ -788,14 +788,14 @@ static u_char *
 /*****************************************************************************************************/
 reconv(recobe_conv cnv) {                                                                        /****
  *****************************************************************************************************/
-    u_char       *tabout = NULL;
-    int           midenco;
-    int           inarray;
-    int           interlo;
-    int           interhi;
-    const u_char *tabin;
-    int           indx;
-    int           outx;
+    int           midenco ;
+    int           inarray ;
+    int           interlo = 0;
+    int           interhi = 0;
+    u_char       *tabout  = NULL;
+    const u_char *tabin   ;
+    int           indx    ;
+    int           outx    ;
 
     if  (  (RECOBE_TEXT == cnv.domain)
         && (TEXT_L > cnv.encosrc)
@@ -817,7 +817,7 @@ reconv(recobe_conv cnv) {
                     inarray = 1;
                 }
                 if  (outx < interlo) {
-                    tabout[outx] = outx;
+                    tabout[outx] = (u_char)outx;
                 } else {
                     tabout[outx] = tabin[indx++];
                 }
@@ -832,9 +832,9 @@ reconv(recobe_conv cnv) {
                     inarray = 1;
                 }
                 if  (outx < interlo) {
-                    tabout[outx] = outx;
+                    tabout[outx] = (u_char)outx;
                 } else {
-                    tabout[tabin[indx++]] = outx;
+                    tabout[tabin[indx++]] = (u_char)outx;
                 }
                 if  (outx >= interhi) inarray = 0;
             }
@@ -849,7 +849,7 @@ reconv(recobe_conv cnv) {
             for (midenco = 1; midenco < TEXT_L; ++midenco) {
                 tabo1 = NULL;
                 tabo2 = NULL;
-                conv1.encodst = conv2.encosrc = midenco;
+                conv1.encodst = conv2.encosrc = (u_int64_t)midenco;
                 if  (  !!(tabi1 = intercode[conv1.encosrc][conv1.encodst])
                     || !!(tabi1 = intercode[conv1.encodst][conv1.encosrc])
                     ) {
@@ -887,13 +887,13 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encosrc = codnumbyid(name);
+        cnv.encosrc = codnumbyid((const u_char *)name);
         if  (!name[1]) {
             cnv.nonedst = 1;
         } else if (!!name[2]) {
             cnv.encodst = 0;
         } else {
-            cnv.encodst = codnumbyid(&name[1]);
+            cnv.encodst = codnumbyid((const u_char *)&name[1]);
     }   }
     return(cnv);
 }
@@ -904,4 +904,14 @@ const recobe_c_tdm
 recobe_text_dm =                                                                                 /****
  *****************************************************************************************************
  *****************************************************************************************************/
-{TEXT_L, 1, "TEXT", encolist, codnumbyid, convbyname, {reconv}};
+{ TEXT_L
+, 1
+#ifdef __amd64__
+, 0
+#endif
+, "TEXT"
+, encolist
+, codnumbyid
+, convbyname
+, {reconv}
+};
