@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2020..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2020..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2020..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: util.c,v 1.24 2022/08/28 00:56:28 babolo Exp $"
+#ident "@(#) Copyright (C)2020..2025 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: util.c,v 1.33 2025/12/21 18:27:27 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -40,9 +40,15 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <stdio.h>
-#include <malloc_np.h>
 #include <babolo/BLINflag.h>
 #include <mife.h>
+
+#ifdef BLIN_OSLinux
+# include <malloc.h>
+#else
+# include <malloc_np.h>
+#endif
+
 #include "recobe.h"
 
 static recobe_chunk *
@@ -67,11 +73,11 @@ recobe_getmife(recobe_chain *chain) {
         goto out;
     }
     md = chain->converdata;
-    ifBLIN_QX3("+ %08X %p of=%lld ob=%u", chain->flags, chain, md->ofpoint, chain->outblock);
+    ifBLIN_QX3("+ %08X %p of=%"BLIN_O"d ob=%u", chain->flags, chain, md->ofpoint, chain->outblock);
     if  (chain->flags & RECOBE_USED) toff = md->ofpoint + chain->outblock;
     ifBLIN_QX3("  toff=%"BLIN_O"d", toff);
     if  (!(inin = mife_window(md, toff, (ssize_t)chain->inblock))) {
-        ifBLIN_QW0("mife_window(,%"BLIN_D",%"BLIN_O"d)", toff, (ssize_t)chain->inblock);
+        ifBLIN_QW0("mife_window(,%"BLIN_O"d,%zd)", toff, (ssize_t)chain->inblock);
         goto out;
     }
     if  (0 > (insz = mife_ctlsize(md))) {
@@ -80,15 +86,15 @@ recobe_getmife(recobe_chain *chain) {
     } else if (insz > (ssize_t)chain->inblock) {
         insz = (ssize_t)chain->inblock;
     }
-    chain->outblock = insz;
+    chain->outblock = (u_int32_t)insz;
     chain->flags |= RECOBE_USED | RECOBE_DOEND;
-    if  (!(chunk = recobe_chunknew(chain, insz, insz, !insz ? NULL : inin))) {
-        ifBLIN_QW0("recobe_chunknew %d", insz);
+    if  (!(chunk = recobe_chunknew(chain, (u_int32_t)insz, (u_int32_t)insz, !insz ? NULL : inin))) {
+        ifBLIN_QW0("recobe_chunknew %zd", insz);
         goto out;
     }
 out:
     RECOBE_CHUNK(chunk);
-    ifBLIN_QX3("- %"BLIN_X, chunk);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chunk));
     return(chunk);
 #   undef blin_internal_flags
 }
@@ -108,7 +114,7 @@ recobe_openmd(recobe_conf *cf, mife_descriptor *md, u_int32_t chunksize) {
 
     ifBLIN_QX3("+ [%d]", chunksize);
     if  (!(chain = malloc(sizeof(recobe_chain)))) {
-        ifBLIN_QW0("malloc(%d)", sizeof(recobe_chain));
+        ifBLIN_QW0("malloc(%zd)", sizeof(recobe_chain));
         goto out;
     }
     chain->converdata = md;
@@ -126,7 +132,7 @@ recobe_openmd(recobe_conf *cf, mife_descriptor *md, u_int32_t chunksize) {
     chain->ecode = cf->ecode;
 out:
     RECOBE_CHAIN(chain);
-    ifBLIN_QX3("- %"BLIN_X, chain);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chain));
     return(chain);
 #   undef blin_internal_flags
 }
@@ -163,7 +169,7 @@ recobe_openfile(recobe_conf *cf, const char *filename, u_int32_t chunksize) {
     }   }
     chain = recobe_openmd(cf, md, chunksize);
 out:
-    ifBLIN_QX3("- %"BLIN_X, chain);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chain));
     return(chain);
 #   undef blin_internal_flags
 }
@@ -207,7 +213,7 @@ recobe_inword(recobe_chain *chain, recobe_chunk *chunk, u_int64_t *wchr) {
     const u_char *c = recobe_chunktext(chunk);
     int           ex = 0;
 
-    ifBLIN_QX3( "+ %08X %"BLIN_X" %"BLIN_X" %u+%u %u"
+    ifBLIN_QX3( "+ %08X %"BLIN_X" %"BLIN_X" %u+%"BLIN_O"u %u"
               , chain->flags
               , BLIN_I(chain)
               , BLIN_I(chunk)
@@ -217,13 +223,13 @@ recobe_inword(recobe_chain *chain, recobe_chunk *chunk, u_int64_t *wchr) {
               );
     if  (!recobe_chunksize(chunk)) goto out;
     if  (chunk->position + l > chunk->length) {
-        ifBLIN_QX2("Long %u+%u %u", chunk->position, l, chunk->length);
-        ex = -(int)recobe_chunksize(chunk);
+        ifBLIN_QX2("Long %u+%"BLIN_O"u %u", chunk->position, l, chunk->length);
+        ex = -EX_NOINPUT;
         errno = ENOSPC;
         goto out;
     }
     if  (!(chain->flags & RECOBE_ORDER)) {
-        *wchr = recobe_load(&c[ex], l);
+        *wchr = recobe_load(&c[ex], (ssize_t)l);
         ex += l;
         chunk->position += l;
     }
@@ -242,7 +248,7 @@ recobe_inword(recobe_chain *chain, recobe_chunk *chunk, u_int64_t *wchr) {
             goto out;
     }   }
     if  (!!(chain->flags & RECOBE_ORDER)) {
-        *wchr = recobe_load(&c[ex], -l);
+        *wchr = recobe_load(&c[ex], -(ssize_t)l);
         ex += l;
         chunk->position += l;
     }
@@ -275,20 +281,21 @@ recobe_outword(recobe_chain *chain, recobe_chunk *chunk, u_int64_t wchr) {
               , chunk->size
               );
     if  (chunk->size < chunk->length + l) {
-        ifBLIN_QX0("size=%u < length=%u + outwlen=%u", chunk->size, chunk->length, l);
+        ifBLIN_QX0("size=%u < length=%u + outwlen=%"BLIN_O"u", chunk->size, chunk->length, l);
         errno = ENOSPC;
         ex = -EX_UNAVAILABLE;
     } else if ((8 > chain->outwlen) && ((1ULL << (chain->outwlen * 8)) <= wchr)) {
-        ifBLIN_QX1("length %016llX > %u", wchr, chain->outwlen);
+        ifBLIN_QX1("length %016"BLIN_O"X > %u", wchr, chain->outwlen);
         errno = ERANGE;
         ex = -EX_CANTCREAT;
     } else {
         recobe_store( &chunk->chunk[chunk->length]
-                    , (chain->flags & RECOBE_ORDER) ? -l : l
+                    , (chain->flags & RECOBE_ORDER) ? -(ssize_t)l : (ssize_t)l
                     , wchr
                     )
         ;
-        chunk->length += (ex = l);
+        chunk->length += l;
+        ex = (int)l;
     }
     ifBLIN_QX3("- %d %u+%u %u", ex, chunk->position, chunk->length, chunk->size);
     return(ex);
@@ -362,10 +369,10 @@ recobe_chunknew(recobe_chain *chain, u_int32_t sz, u_int32_t ln, const u_char *i
 
 #   define blin_internal_flags (chain->flags)
     if  (!(newchunk = malloc(sz + sizeof(recobe_chunk)))) {
-        ifBLIN_QW0("No mem %d", sz + sizeof(recobe_chunk));
+        ifBLIN_QW0("No mem %zd", sz + sizeof(recobe_chunk));
         goto out;
     }
-    newchunk->size = malloc_usable_size(newchunk) - sizeof(recobe_chunk);
+    newchunk->size = (u_int32_t)(malloc_usable_size(newchunk) - sizeof(recobe_chunk));
     newchunk->length = (ln > sz) ? 0 : ln;
     newchunk->position = 0;
     if  (!in && !sz && !ln) newchunk->position = RECOBE_EOT;
@@ -504,7 +511,7 @@ recobe_openc(recobe_conf *cf, const char *p, int domain, recobe_chain *next) {
 
     ifBLIN_QX3("+ d%d:%s", domain, p);
     if  (!(chain = malloc(sizeof(recobe_chain)))) {
-        ifBLIN_QW0("malloc(%d)", sizeof(recobe_chain));
+        ifBLIN_QW0("malloc(%zd)", sizeof(recobe_chain));
         goto out;
     }
     chain->cf = cf;
@@ -537,7 +544,7 @@ recobe_openc(recobe_conf *cf, const char *p, int domain, recobe_chain *next) {
     chain->outwnum = 1;
 out:
     RECOBE_CHAIN(chain);
-    ifBLIN_QX3("- %"BLIN_X, chain);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chain));
     return(chain);
 #   undef blin_internal_flags
 }
@@ -548,7 +555,7 @@ recobe_chunk *
  ****      in  inlen  chain                         ****
  *****************************************************************************************************
                                                                                                   ****/
-recobe_chainarr(recobe_chain *chain, size_t inlen, void *in) {                                   /****
+recobe_chainarr(recobe_chain *chain, size_t inlen, void const *in) {                             /****
                                                                                                   ****
  *****************************************************************************************************
  *****************************************************************************************************/
@@ -559,7 +566,7 @@ recobe_chainarr(recobe_chain *chain, size_t inlen, void *in) {
 
 #   define blin_internal_flags (chain->flags)
     if  (!(cf = calloc(1, sizeof(recobe_conf)))) {
-        ifBLIN_QW0("calloc %d", sizeof(recobe_conf));
+        ifBLIN_QW0("calloc %zd", sizeof(recobe_conf));
         goto out;
     }
     cf->flags = chain->flags;
@@ -602,7 +609,7 @@ recobe_openk(recobe_conf *cf, const char *p, int domain, recobe_chain *next) {
 
     ifBLIN_QX3("+ w:%s %"BLIN_X, p, BLIN_I(next));
     if  (!(chain = malloc(sizeof(recobe_chain)))) {
-        ifBLIN_QW0("malloc(%d)", sizeof(recobe_chain));
+        ifBLIN_QW0("malloc(%zd)", sizeof(recobe_chain));
         goto out;
     }
     if  (!!domain) {
@@ -619,7 +626,6 @@ recobe_openk(recobe_conf *cf, const char *p, int domain, recobe_chain *next) {
     }
     chain->next = next;
     chain->converdata = cf->mod;
-    chain->flags |= RECOBE_CNVDFREE;
     chain->cf = cf;
     chain->flags = cf->flags & ~(RECOBE_USED | RECOBE_CHAINER | RECOBE_DOEND);
     chain->tail = NULL;
@@ -645,7 +651,7 @@ recobe_openk(recobe_conf *cf, const char *p, int domain, recobe_chain *next) {
     if  (RECOBE_ERHEXPRT & chain->flags) chain->outwnum += 2 * chain->inwnum;
 out:
     RECOBE_CHAIN(chain);
-    ifBLIN_QX3("- %"BLIN_X, chain);
+    ifBLIN_QX3("- %"BLIN_X, BLIN_I(chain));
     return(chain);
 #   undef blin_internal_flags
 }
