@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: wchar.c,v 1.69 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2014..2025 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: wchar.c,v 1.77 2025/12/21 18:27:27 babolo Exp $"
 
 #define MIFE_COMPAT     5
 #define BLIN_COMPAT     4
@@ -86,13 +86,13 @@ kode_8[] = {"UCS9"            , NULL};
                                                                                                  /****/
 static const char *                                                                              /****/
 kode_9[] = {"UCS10"           , NULL};                                                           /****/
-                                                                                                  /****/
+                                                                                                 /****/
 static const char *                                                                              /****/
 kode_Z[] = {"SWAPcASE"        , NULL};                                                           /****/
                                                                                                  /****/
 static const char *                                                                              /****/
 kode_Y[] = {"UP/lo"           , NULL};                                                           /****/
-                                                                                                /****/
+                                                                                                 /****/
 static const char *                                                                              /****/
 kode_P[] = {"Puny"            , NULL};                                                           /****/
                                                                                                  /****/
@@ -107,33 +107,33 @@ static const recobe_c_tnm
 encolist[WIDE_L] =                                                                               /****
                                                                                                   ****
  *****************************************************************************************************/
-{ { NULL, NULL,     NULL}
-, { "k" , &kode_k,  NULL}
-, { "u" , &kode_u,  NULL}
-, { "0" , &kode_0,  NULL}
-, { "1" , &kode_1,  NULL}
-, { "2" , &kode_2,  NULL}
-, { "3" , &kode_3,  NULL}
-, { "4" , &kode_4,  NULL}
-, { "5" , &kode_5,  NULL}
-, { "6" , &kode_6,  NULL}
-, { "7" , &kode_7,  NULL}
-, { "8" , &kode_8,  NULL}
-, { "9" , &kode_9,  NULL}
-, { "Z" , &kode_Z,  NULL}
-, { "Y" , &kode_Y,  NULL}
-, { "P" , &kode_P,  NULL}
-, { "p" , &kode_p,  NULL}
+{ { NULL                , NULL   , NULL}
+, { (const u_char *)"k" , &kode_k, NULL}
+, { (const u_char *)"u" , &kode_u, NULL}
+, { (const u_char *)"0" , &kode_0, NULL}
+, { (const u_char *)"1" , &kode_1, NULL}
+, { (const u_char *)"2" , &kode_2, NULL}
+, { (const u_char *)"3" , &kode_3, NULL}
+, { (const u_char *)"4" , &kode_4, NULL}
+, { (const u_char *)"5" , &kode_5, NULL}
+, { (const u_char *)"6" , &kode_6, NULL}
+, { (const u_char *)"7" , &kode_7, NULL}
+, { (const u_char *)"8" , &kode_8, NULL}
+, { (const u_char *)"9" , &kode_9, NULL}
+, { (const u_char *)"Z" , &kode_Z, NULL}
+, { (const u_char *)"Y" , &kode_Y, NULL}
+, { (const u_char *)"P" , &kode_P, NULL}
+, { (const u_char *)"p" , &kode_p, NULL}
 };
 
-static int
+static u_int
 /*****************************************************************************************************
                                                                                                   ****/
-codnumbyid(const char *nm) {                                                                     /****
+codnumbyid(const u_char *nm) {                                                                   /****
                                                                                                   ****
  *****************************************************************************************************/
-    int   r = 0;
-    int   i;
+    u_int   r = 0;
+    u_int   i;
 
     for (i = 1; i < WIDE_L; ++i) {
         if  (nm[0] == encolist[i].encoid[0]) {
@@ -154,13 +154,13 @@ convbyname(const char *name) {
     if  (!name || !name[0]) {
         cnv.nonesrc = cnv.nonedst = 1;
     } else {
-        cnv.encosrc = codnumbyid(name);
+        cnv.encosrc = codnumbyid((const u_char *)name);
         if  (!name[1]) {
             cnv.nonedst = 1;
         } else if (!!name[2]) {
             cnv.encodst = 0;
         } else {
-            cnv.encodst = codnumbyid(&name[1]);
+            cnv.encodst = codnumbyid((const u_char *)&name[1]);
     }   }
     return(cnv);
 }
@@ -177,15 +177,16 @@ un(recobe_chain *chain, recobe_chunk *chunk) {
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    intail = recobe_chunksize(chain->tail);
+    intail = (ssize_t)recobe_chunksize(chain->tail);
     wchr = recobe_uload(&chain->tail->chunk[chain->tail->position], &intail);
     if  (0 > intail) {
-        chain->tail->position += ~intail;
+        chain->tail->position += ~(size_t)intail;
         ifBLIN_QX1("uload");
         ex = -1;
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
-    chain->tail->position += intail;
+    chain->tail->position += (size_t)intail;
     if  (0 > (ex = recobe_outword(chain, chunk, wchr))) {
         ifBLIN_QW2("outword");
         ex = 0;
@@ -213,7 +214,8 @@ nw(recobe_chain *chain, recobe_chunk *chunk) {
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
     pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
-        ifBLIN_QW1("inword");
+        ifBLIN_QW1("inword %d", ex);
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     trail = 0;
@@ -256,25 +258,26 @@ wn(recobe_chain *chain, recobe_chunk *chunk) {
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
     pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
-        ifBLIN_QW1("inword");
+        ifBLIN_QW1("inword %d", ex);
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     if  (  ((wchr & 0xFC00) == 0xD800)
-        && (chain->inwlen + chain->tail->position > chain->tail->length)
+        && (chain->inwlen + pos > chain->tail->length)
         ) {
-        ifBLIN_QX1("Surrogate");
+        ifBLIN_QX1("Surrogate0: %016"BLIN_O"X", wchr);
         ex = -1;
         goto out;
     }
     if  ((4 >= chain->outwlen) && ((wchr & 0xFC00) == 0xDC00)) {
-        ifBLIN_QX1("Surrogate");
+        ifBLIN_QX1("Surrogate1: %016"BLIN_O"X", wchr);
         ex = -1;
         goto out;
     }
     if  ((wchr & 0xFC00) == 0xD800) {
-        trail = wchr;
+        trail = (u_int16_t)wchr;
         if  ((0 > (ex = recobe_inword(chain, chain->tail, &wchr))) || ((wchr & 0xFC00) != 0xDC00)) {
-            ifBLIN_QX1("Surrogate");
+            ifBLIN_QX1("Surrogate2: %016"BLIN_O"X", wchr);
             ex = -1;
             goto out;
         }
@@ -297,18 +300,17 @@ nn(recobe_chain *chain, recobe_chunk *chunk) {
                                                                                                   ****
  *****************************************************************************************************/
     u_int64_t     wchr;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
-        ifBLIN_QW1("inword");
+        ifBLIN_QW1("inword %d", ex);
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     if  ((8 > chain->outwlen) && ((1ULL << (chain->outwlen * 8)) <= wchr)) {
-        ifBLIN_QX1("Long");
+        ifBLIN_QX1("Long outwlen %u", chain->outwlen);
         ex = -1;
         goto out;
     }
@@ -329,18 +331,17 @@ nk(recobe_chain *chain, recobe_chunk *chunk) {
                                                                                                   ****
  *****************************************************************************************************/
     u_int64_t     wchr;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword %d", ex);
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     if  ((0x00FFFF < wchr) || !recobe_1k[wchr]) {
-        ifBLIN_QX1("Long");
+        ifBLIN_QX1("Long or NO: %016"BLIN_O"X", wchr);
         ex = -ex;
         goto out;
     };
@@ -389,24 +390,28 @@ nu(recobe_chain *chain, recobe_chunk *chunk) {
  *****************************************************************************************************/
     u_int64_t     wchr;
     int           outw;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
-    if  (chunk->size < chunk->length + recobe_utest(wchr)) {
+    if  (chunk->size < chunk->length + (u_int)recobe_utest(wchr)) {
         ex = 0;
         ifBLIN_QX1("Long");
         goto out;
     }
     outw = recobe_utest(wchr);
-    if  (chunk->size < chunk->length + outw) {
-        ifBLIN_QX0("size=%u < length=%u + utest(%llX)=%u", chunk->size, chunk->length, wchr, outw);
+    if  (chunk->size < chunk->length + (u_int)outw) {
+        ifBLIN_QX0( "size=%u < length=%u + utest(%"BLIN_O"X)=%u"
+                  , chunk->size
+                  , chunk->length
+                  , wchr
+                  , outw
+                  );
         errno = ENOSPC;
         ex = -EX_CANTCREAT;
     }
@@ -415,7 +420,7 @@ nu(recobe_chain *chain, recobe_chunk *chunk) {
         ex = -ex;
         goto out;
     }
-    chunk->length += outw;
+    chunk->length += (u_int)outw;
 out:
     ifBLIN_QX3("- %d", ex);
     return(ex);
@@ -429,17 +434,16 @@ Yn(recobe_chain *chain, recobe_chunk *chunk) {
                                                                                                   ****
  *****************************************************************************************************/
     u_int64_t     wchr;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
-    chain->tail->position += ex;
+    chain->tail->position += (u_int)ex;
     wchr ^= recobe_unicodelower(wchr);
     if  ((8 > chain->outwlen) && ((1ULL << (chain->outwlen * 8)) <= wchr)) {
         ifBLIN_QX1("Long");
@@ -463,14 +467,13 @@ nY(recobe_chain *chain, recobe_chunk *chunk) {
                                                                                                   ****
  *****************************************************************************************************/
     u_int64_t     wchr;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
     wchr ^= recobe_unicodeupper(wchr);
@@ -497,17 +500,16 @@ nZ(recobe_chain *chain, recobe_chunk *chunk) {
  *****************************************************************************************************/
     u_int64_t     wchr;
     u_int64_t     wchz;
-    u_int32_t     pos;
     int           ex;
 
 #   define blin_internal_flags (chain->flags)
     ifBLIN_QX3("+ %08X %"BLIN_X, chain->flags, BLIN_I(chain));
-    pos = chain->tail->position;
     if  (0 > (ex = recobe_inword(chain, chain->tail, &wchr))) {
         ifBLIN_QW1("inword");
+        if  (!chunk->length && !chunk->position) chunk->position = RECOBE_EOT;
         goto out;
     }
-    chain->tail->position += ex;
+    chain->tail->position += (u_int)ex;
     wchz = recobe_unicodeupper(wchr);
     if  (!wchz) wchz = recobe_unicodelower(wchr);
     wchr ^= wchz;
@@ -697,4 +699,14 @@ recobe_wide_dm =
                                                                                                   ****
  *****************************************************************************************************
  *****************************************************************************************************/
-{WIDE_L, 2, "WIDE", encolist, codnumbyid, convbyname, {.param = param}};
+{ WIDE_L
+, 2
+#ifdef __amd64__
+, 0
+#endif
+, "WIDE"
+, encolist
+, codnumbyid
+, convbyname
+, {.param = param}
+};
