@@ -1,5 +1,5 @@
 /*-
- * Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/
+ * Copyright (C)2014..2025 @BABOLO http://www.babolo.ru/
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,8 +24,8 @@
  * SUCH DAMAGE.
  */
 
-#ident "@(#) Copyright (C)2014..2021 @BABOLO http://www.babolo.ru/"
-#ident "@(#) $Id: recobe.c,v 1.79 2021/12/05 17:53:10 babolo Exp $"
+#ident "@(#) Copyright (C)2014..2025 @BABOLO http://www.babolo.ru/"
+#ident "@(#) $Id: recobe.c,v 1.88 2025/12/21 18:30:41 babolo Exp $"
 
 #define BLIN_COMPAT     4
 #define MIFE_COMPAT     5
@@ -47,7 +47,7 @@
 #include <babolo/BLINflag.h>
 #include <babolo/parser.h>
 #include <mife.h>
-#include "recobe.h"
+#include "lib/recobe.h"
 
 #define RECOBE_CASE_OPTS opts
 #define RECOBE_CASE_OUT  out
@@ -104,15 +104,15 @@ static void
 usagem() {                                                                                       /****
  *****************************************************************************************************/
     fprintf( stderr
-           , "For TQ [=[ft[=ft]...[#M[$m]]]]\n"
+           , "For 0Q [=[ft[=ft]...[#M[$m]]]]\n"
              "       where = hex indicator and LF canseller\n"
              "             f symbol to translate from\n"
              "             t symbol to translate to\n"
-             "             # some symbol not equel =\n"
+             "             # some symbol not equal =\n"
              "             M number for max out string length\n"
-             "             $ some symbol not equel =\n"
+             "             $ some symbol not equal = or digit\n"
              "             m string length cuted on space if possible\n"
-             "    nQ hex indicator string\n"
+             "    [0-7][DX] Single byte char up to this code\n"
            )
     ;
 }
@@ -121,7 +121,11 @@ static void
 /*****************************************************************************************************/
 usagec() {                                                                                       /****
  *****************************************************************************************************/
-    int               i, k, m, n, u;
+    int i;
+    int k;
+    int m;
+    int n;
+    int u;
 
     for (i = 0; !!recobe_collection.domains[i]; i++) {
         m = 0;
@@ -319,13 +323,13 @@ main(int argc, char **argv) {
         case 't': {   mife_descriptor *ifile = NULL;
                       ssize_t          insz;
                       u_char          *inin;
-                      char             f[2] = "0";
-                      char             t[2] = "0";
-                      const char      *o;
+                      u_char           f   [2] = "0";
+                      u_char           t   [2] = "0";
+                      const char      *o   ;
 
                 ;     o = babolo_getoptsarg(opts->bos);
-                ;     f[0] = o[0];
-                ;     t[0] = o[1];
+                ;     f[0] = (u_char)o[0];
+                ;     t[0] = (u_char)o[1];
                 ;     if  (!(ifile = mife_init(MIFE_SLID))) {
                 ;         ifBLIN_QW0("mife_init");
                 ;         ex = -EX_IOERR;
@@ -361,15 +365,14 @@ main(int argc, char **argv) {
                 ; break;
         case 'v': BLIN_VERBOSE(opts->cf.flags);
                 ; break;
-        case '=': {   const char *Tflag;
+        case '=': {   const u_char *Tflag;
 
-                ;     Tflag = babolo_getoptsarg(opts->bos);
-                ;     ifBLIN_QX4("%02X(%c)", *Tflag & 0x0FF, *Tflag);
-                ;     if  (0 > *Tflag) {
+                ;     if  (!(Tflag = (const u_char *)babolo_getoptsarg(opts->bos))) {
                 ;         ifBLIN_QW0("babolo_getopts");
                 ;         ex = -EX_USAGE;
                 ;         goto out;
                 ;     }
+                ;     ifBLIN_QX4("%02X(%c)", *Tflag & 0x0FF, *Tflag);
                 ;     switch(*Tflag) {
                 ;     case '0': blin_ctl(BLIN_CTL_DUMP);    exit(EX_OK);
                 ;     case '1': babolo_optest(flar);        exit(EX_OK);
